fn shorten_paths(editor: &SyntaxEditor, node: &SyntaxNode, path: &Path)Expand description
Mutates node to shorten path in all descendants of node.
fn shorten_paths(editor: &SyntaxEditor, node: &SyntaxNode, path: &Path)Mutates node to shorten path in all descendants of node.